==> haskell-loop-0.3.0-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-GOJBHeppNhFGa3tPj6z9l
key:                  loop-0.3.0-GOJBHeppNhFGa3tPj6z9l
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  7a58cd2b7fa476cb76402643f7fa42ef
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/loop-0.3.0
hs-libraries:         HSloop-0.3.0-GOJBHeppNhFGa3tPj6z9l
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-157-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-EQOxE6vt6swILymCwH0wy4
key:                  loop-0.3.0-EQOxE6vt6swILymCwH0wy4
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  68ec4c5774fd59c8815dc64444e781fb
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/loop-0.3.0
hs-libraries:         HSloop-0.3.0-EQOxE6vt6swILymCwH0wy4
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
